==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WaterfallSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeriesDescription } from "./HorizontalAnchoredCategorySeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WaterfallSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeriesDescription, _super);
    function WaterfallSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.ev = null;
        _this.er = 0;
        _this.es = 0;
        _this.ew = null;
        return _this;
    }
    WaterfallSeriesDescription.prototype.get_type = function () {
        return "WaterfallSeries";
    };
    Object.defineProperty(WaterfallSeriesDescription.prototype, "negativeBrush", {
        get: function () {
            return this.ev;
        },
        set: function (a) {
            this.ev = a;
            this.e("NegativeBrush");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WaterfallSeriesDescription.prototype, "radiusX", {
        get: function () {
            return this.er;
        },
        set: function (a) {
            this.er = a;
            this.e("RadiusX");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WaterfallSeriesDescription.prototype, "radiusY", {
        get: function () {
            return this.es;
        },
        set: function (a) {
            this.es = a;
            this.e("RadiusY");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WaterfallSeriesDescription.prototype, "negativeOutline", {
        get: function () {
            return this.ew;
        },
        set: function (a) {
            this.ew = a;
            this.e("NegativeOutline");
        },
        enumerable: false,
        configurable: true
    });
    WaterfallSeriesDescription.$t = markType(WaterfallSeriesDescription, 'WaterfallSeriesDescription', HorizontalAnchoredCategorySeriesDescription.$);
    return WaterfallSeriesDescription;
}(HorizontalAnchoredCategorySeriesDescription));
export { WaterfallSeriesDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/WaterfallSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeriesDescription } from "./HorizontalAnchoredCategorySeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WaterfallSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WaterfallSeriesDescription, _super);
    function WaterfallSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.g5 = null;
        _this.g1 = 0;
        _this.g2 = 0;
        _this.g6 = null;
        return _this;
    }
    WaterfallSeriesDescription.prototype.get_type = function () {
        return "WaterfallSeries";
    };
    Object.defineProperty(WaterfallSeriesDescription.prototype, "negativeBrush", {
        get: function () {
            return this.g5;
        },
        set: function (a) {
            this.g5 = a;
            this.g("NegativeBrush");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WaterfallSeriesDescription.prototype, "radiusX", {
        get: function () {
            return this.g1;
        },
        set: function (a) {
            this.g1 = a;
            this.g("RadiusX");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WaterfallSeriesDescription.prototype, "radiusY", {
        get: function () {
            return this.g2;
        },
        set: function (a) {
            this.g2 = a;
            this.g("RadiusY");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WaterfallSeriesDescription.prototype, "negativeOutline", {
        get: function () {
            return this.g6;
        },
        set: function (a) {
            this.g6 = a;
            this.g("NegativeOutline");
        },
        enumerable: false,
        configurable: true
    });
    WaterfallSeriesDescription.$t = markType(WaterfallSeriesDescription, 'WaterfallSeriesDescription', HorizontalAnchoredCategorySeriesDescription.$);
    return WaterfallSeriesDescription;
}(HorizontalAnchoredCategorySeriesDescription));
export { WaterfallSeriesDescription };
